//_____________________________________________________________________________
//
// Copyright (C) 2018                   Mobsya                   CH-1020 Renens
//_____________________________________________________________________________
//
// PROJECT   Thymio-III
//_____________________________________________________________________________
//
//! \file    main.c
//! \brief   This module provides the useful functions to use the xxx
//!
//! \author  Vincent Gonet
//!
//! \version $Id: main.c 18076 2017-04-20 12:28:12Z v.gonet $
//_____________________________________________________________________________

//-----------------------------------------------------------------------------
// Include Section
//-----------------------------------------------------------------------------

#include <string.h>

#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "freertos/portmacro.h"
//#include "freertos/queue.h"
//#include "freertos/semphr.h"

#include "sdkconfig.h"

#include "esp_log.h"

#include "behavior.h"
#include "comm.h"
#include "gpio.h"
#include "leds.h"
#include "mode.h"
#include "mp3.h"
#include "power.h"
#include "sensors.h"
#include "sound.h"
#include "stm32.h"
#include "timer.h"
#include "timer_hw.h"
#include "uart.h"

//-----------------------------------------------------------------------------
// Constants/Macros Definitions
//-----------------------------------------------------------------------------

#define DEFAULT_WIFI_SSID           CONFIG_WIFI_SSID
#define DEFAULT_WIFI_PASSWORD       CONFIG_WIFI_PASSWORD

//-----------------------------------------------------------------------------
// Types Definitions
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Exported Global Data
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Private Data
//-----------------------------------------------------------------------------

static const char* Tag = "main";

static int16_t Target[2] = {0, 0};
static int16_t OldTarget[2] = {0, 0};

static T_Settings Settings;
static T_Settings OldSettings;

//-----------------------------------------------------------------------------
// Private Functions Prototypes
//-----------------------------------------------------------------------------

static void Settings_Init(void);

//-----------------------------------------------------------------------------
// Inline Code Definition
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Functions Implementation
//-----------------------------------------------------------------------------

//_____________________________________________________________________________

int app_main(void)
{
  static int appCore1 = 0;
  static int appCore2 = 1;

#if 0
  WIFI_InitNVS();
  WIFI_Init();
  //WifiUpdate_Init();

  while (!WIFI_IsConnected())
  {}
#endif

  Settings_Init();
#if 0
  FileSystem_Init();
  FileSystem_CreateSettingsFile();
  //FileSystem_ReadFile();
  FileSystem_ReadSettingsFile();
  FileSystem_WriteSettingsFile();
  FileSystem_ReadSettingsFile();
  FileSystem_UpdateSettings(29, 56);
  FileSystem_WriteSettingsFile();
  FileSystem_ReadSettingsFile();
#endif

  Gpio_Init();
  Power_Init();

  UART_Init();

  Comm_Init();

  TimerHw_Init();

  Sensors_Init();
  Mode_Init();
  Mode_InitVM();

  //MP3_Init();

  Timer_Init(0, 0, 1, 0.000125);  // Timer used to run the SensorTask
  Timer_Init(0, 1, 1, 1);         // Timer used to handle the IR_SENSE_BACK_RIGHT_PIN

//#if 0
  xTaskCreatePinnedToCore(
	Behavior_RunTask, // Function to implement the task
    "behavior",   // Name of the task
    2048,         // Stack size in words
    NULL,         // Task input parameter
    2,            // Priority of the task
    NULL,         // Task handle
    appCore1);    // Core where the task should run
//#endif
#if 0
  xTaskCreatePinnedToCore(
    MP3_Task,
    "sound",      // Name of the task
    2048,         // Stack size in words
    NULL,         // Task input parameter
    2,            // Priority of the task
    NULL,         // Task handle
    appCore1);    // Core where the task should run
#endif
//#if 0
  xTaskCreatePinnedToCore(
    Comm_RunTask,    // Function to implement the task
    "comm",      // Name of the task
    2048,        // Stack size in words
    NULL,        // Task input parameter
    3,           // Priority of the task
    NULL,        // Task handle
    appCore1);   // Core where the task should run
//#endif
//#if 0
  xTaskCreatePinnedToCore(
    Sensor_RunTask,  // Function to implement the task
    "sensor",    // Name of the task
    2048,        // Stack size in words
    NULL,        // Task input parameter
    9,           // Priority of the task
    NULL,        // Task handle
    appCore1);   // Core where the task should run
//#endif

  return 0;
}

//_____________________________________________________________________________

static void Settings_Init()
{
  Settings.LeftMotor  = 256;
  Settings.RightMotor = 256;

  OldSettings.LeftMotor  = 0;
  OldSettings.RightMotor = 0;
}

//_____________________________________________________________________________
