//_____________________________________________________________________________
//
// Copyright (C) 2018                   Mobsya                   CH-1020 Renens
//_____________________________________________________________________________
//
// PROJECT   Thymio-III
//_____________________________________________________________________________
//
//! \file    power.c
//! \brief   This module provides the useful functions to manage the power
//!
//! \author  Vincent Gonet
//!
//! \version $Id: power.c 18076 2017-04-20 12:28:12Z v.gonet $
//_____________________________________________________________________________

//-----------------------------------------------------------------------------
// Include Section
//-----------------------------------------------------------------------------

#include "power.h"

#include "board.h"
#include "gpio.h"
#include "stm32.h"

//-----------------------------------------------------------------------------
// Constants/Macros Definitions
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Types Definitions
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Exported Global Data
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Private Data
//-----------------------------------------------------------------------------

static const T_GpioPinConfig PinConfig = {VA_ENABLE_PIN,
                                          E_GpioMode_Output,
                                          E_GpioResistor_None,
                                          E_GpioLevel_Low,
                                          E_GpioInterrupt_Disable
                                         };

static bool EnableSwitchOff = false;

//-----------------------------------------------------------------------------
// Private Functions Prototypes
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Inline Code Definition
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Functions Implementation
//-----------------------------------------------------------------------------

void Power_Init(void)
{
  Gpio_ConfigurePin(&PinConfig);

  Power_EnableVA();
  //Power_DisableVA();
}

//_____________________________________________________________________________

void Power_EnableVA(void)
{
  Gpio_SetPinLevel(VA_ENABLE_PIN, E_GpioLevel_High);
}

//_____________________________________________________________________________

void Power_DisableVA(void)
{
  Gpio_SetPinLevel(VA_ENABLE_PIN, E_GpioLevel_Low);
}

//_____________________________________________________________________________

void Power_SwitchOff(void)
{
  Power_DisableVA();
}

//_____________________________________________________________________________

void Power_EnableSwitchOff(void)
{
  EnableSwitchOff = true;
}

//_____________________________________________________________________________

bool Power_IsSwitchOffEnabled(void)
{
  return EnableSwitchOff;
}
