//_____________________________________________________________________________
//
// Copyright (C) 2018                   Mobsya                   CH-1020 Renens
//_____________________________________________________________________________
//
// PROJECT   Thymio-III
//_____________________________________________________________________________
//
//! \file    uart.c
//! \brief   This module provides the useful functions to use the UART
//!
//! \author  Vincent Gonet
//!
//! \version $Id: uart.c 18076 2017-04-20 12:28:12Z v.gonet $
//_____________________________________________________________________________

//-----------------------------------------------------------------------------
// Include Section
//-----------------------------------------------------------------------------

#include <string.h>

#include "driver/uart.h"
#include "esp_log.h"

#include "uart.h"

#include "board.h"
#include "stm32.h"

//-----------------------------------------------------------------------------
// Constants/Macros Definitions
//-----------------------------------------------------------------------------

#define UART_NUM          UART_NUM_0

#define UART_BAUDRATE        115200u

#define RX_BUFFER_SIZE         1024u
#define TX_BUFFER_SIZE         1024u

//-----------------------------------------------------------------------------
// Types Definitions
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Exported Global Data
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Private Data
//-----------------------------------------------------------------------------

static const char* Tag = "uart";

//static QueueHandle_t UartQueue;

//-----------------------------------------------------------------------------
// Private Functions Prototypes
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Inline Code Definition
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Functions Implementation
//-----------------------------------------------------------------------------

void UART_Init(void)
{
  uart_config_t config =
  {
    .baud_rate = UART_BAUDRATE,
    .data_bits = UART_DATA_8_BITS,
    .parity    = UART_PARITY_DISABLE,
    .stop_bits = UART_STOP_BITS_1,
    .flow_ctrl = UART_HW_FLOWCTRL_DISABLE
  };

  uart_param_config(UART_NUM, &config);
  uart_set_pin(UART_NUM, TXD_ESP32_PIN, RXD_ESP32_PIN, UART_PIN_NO_CHANGE, UART_PIN_NO_CHANGE);
  //uart_driver_install(UART_NUM, RX_BUFFER_SIZE * 2, 0, 0, NULL, 0);
  uart_driver_install(UART_NUM, RX_BUFFER_SIZE, TX_BUFFER_SIZE, 0, NULL, 0);
  //uart_driver_install(UART_NUM, RX_BUFFER_SIZE * 2, TX_BUFFER_SIZE * 2, 20, &UartQueue, 0);

  uart_flush(UART_NUM);

  ESP_LOGI(Tag, "UART is initialized");
}

//_____________________________________________________________________________

void UART_Write(const uint8_t* data, uint16_t size)
{
  if (STM32_IsUSBPortOpen())
  {
    uart_write_bytes(UART_NUM, (const char*)data, size);
  }
}

//_____________________________________________________________________________

int UART_Read(uint8_t* data)
{
  int length = 0;

  ESP_ERROR_CHECK(uart_get_buffered_data_len(UART_NUM, (size_t*)&length));

  length = uart_read_bytes(UART_NUM, data, length, 0u);

  //uart_flush(UART_NUM);

  return length;
}

//_____________________________________________________________________________

int UART_ReadByte(uint8_t* data)
{
  int length = uart_read_bytes(UART_NUM, data, 1u, 500u);

  return length;
}

//_____________________________________________________________________________

bool UART_IsReceptionBufferEmpty(void)
{
  int length = 0;

  ESP_ERROR_CHECK(uart_get_buffered_data_len(UART_NUM, (size_t*)&length));

  return (length == 0);
}

//_____________________________________________________________________________

void UART_WaitUntilTxFifoIsEmpty(void)
{
  ESP_ERROR_CHECK(uart_wait_tx_done(UART_NUM, 100));  // wait timeout is 100 RTOS ticks (TickType_t)
}
